generate_session_id

Function generate_session_id 

pub fn generate_session_id() -> ([u8; 32], String)
Generate a fresh 32-byte session id. The id is what goes into the cookie (base64-encoded, then signed) and what we look up in the sessions table.