Module config

Module config 

Runtime configuration for the sl-map-web server.

Structs

Config
CLI options for sl_map_web.

Enums

ConfigError
Errors that can occur while validating a parsed Config.
ForwardedHeader
Which header to consult for the real client IP behind a trusted proxy.