pub async fn get_for_user(
db: &SqlitePool,
group_id: Uuid,
user_id: Uuid,
) -> Result<GroupView, Error>Expand description
Fetch a single group view if the user is a member of it.
Errors
Returns Error::Database on query failure or Error::NotFound if the
group does not exist or the user is not a member.