pub struct ListLogosResponse {
pub logos: Vec<LogoView>,
}Expand description
Response carrying the listing of logos in a scope.
Fields
logos: Vec<LogoView>the saved logos visible in the requested scope, newest first.