pub async fn grid_rectangle(
user: CurrentUser,
__arg1: State<AppState>,
__arg2: Json<GridRectangleRequest>,
) -> Result<Json<StartedResponse>, Error>Expand description
POST /api/render/grid-rectangle — start a render from explicit corners.
Errors
Returns an error if any of the optional hex colour fields fails to parse, the destination is invalid, or the user is not allowed to save to it.