pub struct ThemeView {
pub theme_id: Uuid,
pub destination: Destination,
pub created_by: Option<Uuid>,
pub created_by_username: Option<String>,
pub created_by_legacy_name: Option<String>,
pub name: String,
pub settings: ThemeSettings,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Expand description
Public, serialisable record of a saved theme.
Fields
theme_id: Uuidthe theme id.
destination: Destinationthe destination the theme belongs to.
created_by: Option<Uuid>the avatar that created the theme, or None if the account is
since deleted.
created_by_username: Option<String>the creator’s username, if the account still exists.
created_by_legacy_name: Option<String>the creator’s legacy name, if the account still exists.
name: Stringthe human-supplied display name.
settings: ThemeSettingsthe presentation settings.
created_at: DateTime<Utc>when the theme was created.
updated_at: DateTime<Utc>when the theme was last renamed or its settings overwritten.