write_render_file

Function write_render_file 

pub async fn write_render_file(
    storage_dir: &Path,
    render_id: Uuid,
    suffix: &str,
    ext: &str,
    bytes: Bytes,
) -> Result<String, Error>
Write the rendered image bytes for a render to disk, returning the filename that should be stored in the DB.

Errors

Returns an Error::Io if the file cannot be written.